<?php

/**
 * @file
 * Config form.
 */

/**
 * Form definition; inline_styles_cleaner_config_form.
 *
 * @param array $form
 *   Drupal $form variable.
 * @param array $form_state
 *   Drupal $form_state variable.
 *
 * @return array $form
 *  Drupal $form variable.
 */
function inline_styles_cleaner_config_form(array $form, array &$form_state) {
  module_load_include('inc', 'inline_styles_cleaner', 'includes/inline_styles_cleaner.common');

  $form['fields_for_clean_fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('Fields settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['fields_for_clean_fieldset']['clean_text_field_summary'] = array(
    '#type' => 'checkbox',
    '#title' => t('Clean summary'),
    '#description' => t('Check it if you want clean summary from "text_with_summary" fields.'),
    '#default_value' => variable_get('clean_text_field_summary', FALSE),
  );

  $form['fields_for_clean_fieldset']['fields_for_clean'] = array(
    '#type' => 'checkboxes',
    '#options' => inline_styles_cleaner_common_get_text_fields_names(),
    '#title' => t('Select fields for cleaning inline styles'),
    '#default_value' => variable_get('fields_for_clean', array()),
  );

  $form['generate_css_fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('Css generator settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['generate_css_fieldset']['generate_css'] = array(
    '#type' => 'checkbox',
    '#title' => t('Generate css styles for selected fields'),
    '#description' => t("Generated css file will be contain clipped inline styles from field's values."),
    '#default_value' => variable_get('generate_css', FALSE),
  );

  $form['generate_css_fieldset']['class_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Class name'),
    '#description' => t("Class name that will be applied to elements with inline styles. It's a part of full future class name. Class name will be: class_name-{entity_id}-{field_name_(value|summary)}-{element_number}"),
    '#default_value' => variable_get('class_name', 'isc'),
    '#states' => array(
      'visible' => array(
        'input[name="generate_css"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form = system_settings_form($form);
  $form['actions']['submit']['#value'] = t('Start processing');
  $form['#submit'][] = 'inline_styles_cleaner_launch_batch';

  return $form;
}

/**
 * Custom submit to launch batches.
 *
 *
 * @param array $form
 *   Drupal $form variable.
 * @param array $form_state
 *   Drupal $form_state variable.
 *
 * @return array $form
 *   Drupal $form variable.
 */
function inline_styles_cleaner_launch_batch(array $form, array &$form_state) {
  module_load_include('inc', 'inline_styles_cleaner', 'includes/inline_styles_cleaner.common');

  $field_names = array_filter(variable_get('fields_for_clean', array()));
  $generate_css_needed = variable_get('generate_css', FALSE);
  $class_name = variable_get('class_name', 'isc');
  $clean_summary_needed = variable_get('clean_text_field_summary', FALSE);

  // We need to check $field_names with empty() function because
  // if user wouldn't select any field he should see warning message.
  if (!empty($field_names)) {
    foreach ($field_names as $field_name) {
      // Prepare batch operations.
      foreach (db_select("field_data_$field_name", $field_name)->fields($field_name)->execute() as $field) {
        $operations[] = array(
          'inline_styles_cleaner_batch_operation',
          array(
            array(
              'clean_summary_needed' => $clean_summary_needed,
              'field_settings' => array(
                'field_name' => $field_name,
                'field_instance' => $field,
              ),
              'css_settings' => array(
                'generate_css_needed' => $generate_css_needed,
                'class_name' => $class_name,
              ),
            ),
          ),
        );
      }
    }

    // We should check that $operation array contains at least one operation.
    // Otherwise there is no sense to launch batch.
    if (isset($operations)) {
      batch_set(array(
        'operations' => $operations,
        'finished' => 'inline_styles_cleaner_batch_finished',
        'file' => drupal_get_path('module', 'inline_styles_cleaner') . '/includes/inline_styles_cleaner.batch.inc',
      ));
    }
    else {
      drupal_set_message(t('There is now instances of selected field(s) in database.'), 'warning');
    }
  }
  else {
    drupal_set_message(t('Please select field(s) to start processing.'), 'warning');
  }
}
